=======
StegArt
=======
Renders a graphical representation of the data provided

StegArt takes the passed input string, converts it to hex, and displays the
resulting hexstring as BGR color using OpenCV. Designed with hexdigests of
hashes in mind, but can be used for binary and ascii input as well.
